#
# spec file for package ghc-dlist
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name dlist
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0
Release:        2.6
Summary:        Difference lists
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
%endif

%description
List-like types supporting O(1) append and snoc operations.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license license.md

%files devel -f %{name}-devel.files
%doc changelog.md readme.md

%changelog
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Aug 12 2020 psimons@suse.com
- Update dlist to version 1.0.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update dlist to version 0.8.0.8.
  Version 0.8.0.8 (2020-04-02) *World Autism Awareness Day*
  - --------------------------------------------------------
  [#]### Package changes
  * Change QuickCheck upper bound from 2.14 to 2.15
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Aug  7 2019 psimons@suse.com
- Update dlist to version 0.8.0.7.
  Version 0.8.0.7 (2019-08-05) *Independence Day in Burkina Faso*
  - --------------------------------------------------------------
  [#]### Package changes
  * Add `MonadFail` instance for GHC >= 8.8
    ([Vanessa McHale](https://github.com/vmchale))
  * Change `deepseq` upper bound to 1.5
    ([Herbert Valerio Riedel](https://github.com/hvr))
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Mar 30 2019 psimons@suse.com
- Update dlist to version 0.8.0.6.
  Version 0.8.0.6 (2019-03-29) *Martyrs' Day in Madagascar*
  - --------------------------------------------------------
  [#]### Package changes
  * Change QuickCheck upper bound from 2.13 to 2.14
* Thu Oct  4 2018 psimons@suse.com
- Update dlist to version 0.8.0.5.
  Version 0.8.0.5 (2018-09-13) *Day of the Programmer*
  - ---------------------------------------------------
  [#]### Package changes
  * Change QuickCheck upper bound from 2.12 to 2.13
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update dlist to version 0.8.0.4.
  * Change QuickCheck upper bound from 2.11 to 2.12
  * Make `Data.DList` trustworthy
    ([Bertram Felgenhauer](https://github.com/int-e))
  * Remove quickcheck-instances dependency for tests
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.8.0.3.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.8.0.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.1.2 revision 0 with cabal2obs.
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 0.7.1.2
  * Fix GHC 7.10 warnings due to imports
* Fri Apr 17 2015 mimi.vx@gmail.com
- update to 0.7.1.1
- regenerated spec file
  * Add `IsList` instance for GHC >= 7.8 ([Icelandjack](https://github.com/Icelandjack))
  * Add `NFData` instance (and `deepseq` dependency)
  * Add `IsString` instance
  * Remove deprecated entities
  * Stop supporting `base < 2`
  * Update documentation
  * New type class instances: `Eq`, `Ord`, `Read`, `Show`, `Alternative`,
  and `Foldable`
  * New function `apply` to use instead of `unDL`
  * Deprecate DList constructor and record selector to make it abstract
  (see [#4](https://github.com/spl/dlist/issues/4))
  * Deprecate `maybeReturn` which is not directly relevant to dlists
* Tue May 14 2013 peter.trommler@ohm-hochschule.de
- cabal-rpm new template for spec file
  * more transparent packaging
  * macros don't span spec file sections
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Fri Jan 20 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
